/* ************************************ */
/* Define helper functions */
/* ************************************ */
function saveData(name, data){
  var xhr = new XMLHttpRequest();
  xhr.open('POST', 'write_data.php'); // 'write_data.php' is the path to the php file described above.
  xhr.setRequestHeader('Content-Type', 'application/json');
  xhr.send(JSON.stringify({filename: name, filedata: data}));
}

function assessPerformance() {
	/* Function to calculate the "credit_var", which is a boolean used to
	credit individual experiments in expfactory. */
	var experiment_data = jsPsych.data.getTrialsOfType('poldrack-single-stim')
	var missed_count = 0
	var trial_count = 0
	var rt_array = []
	var rt = 0
		//record choices participants made
	var choice_counts = {}
	choice_counts[-1] = 0
	choice_counts[32] = 0
	for (var i = 0; i < experiment_data.length; i++) {
		if (experiment_data[i].possible_responses != 'none') {
			trial_count += 1
			rt = experiment_data[i].rt
			key = experiment_data[i].key_press
			choice_counts[key] += 1
			if (rt == -1) {
				missed_count += 1
			} else {
				rt_array.push(rt)
			}
		}
	}
	//calculate average rt
	var avg_rt = -1
	if (rt_array.length !== 0) {
		avg_rt = math.median(rt_array)
	} 
	var missed_percent = missed_count/experiment_data.length
	//calculate whether response distribution is okay
	var responses_ok = true
	Object.keys(choice_counts).forEach(function(key, index) {
		if (choice_counts[key] > trial_count * 0.85) {
			responses_ok = false
		}
	})
	credit_var = (missed_percent < 0.4 && (avg_rt > 200) && responses_ok)
	jsPsych.data.addDataToLastTrial({"credit_var": credit_var})
}

var getInstructFeedback = function() {
	return '<div class = centerbox><p class = center-block-text>' + feedback_instruct_text + '</p></div>'
}

var randomDraw = function(lst) {
	var index = Math.floor(Math.random() * (lst.length))
	return lst[index]
};

//shuffles an array
function shuffle(array) {
  var currentIndex = array.length,  randomIndex;

  // While there remain elements to shuffle...
  while (0 !== currentIndex) {

    // Pick a remaining element...
    randomIndex = Math.floor(Math.random() * currentIndex);
    currentIndex--;

    // And swap it with the current element.
    [array[currentIndex], array[randomIndex]] = [
      array[randomIndex], array[currentIndex]];
  }

  return array;
}

//rounds a number to a set number of digits
function roundTo(n, digits) {
    var negative = false;
    if (digits === undefined) {
        digits = 0;
    }
    if (n < 0) {
        negative = true;
        n = n * -1;
    }
    var multiplicator = Math.pow(10, digits);
    n = parseFloat((n * multiplicator).toFixed(11));
    n = (Math.round(n) / multiplicator).toFixed(digits);
    if (negative) {
        n = (n * -1).toFixed(digits);
    }
    return parseFloat(n);
}


// Runs on last trial
var record_acc = function(data, t) {
	var target = t || data.target
	var stim = data.stim
	var key = data.key_press
	
	if (stim == target && key == 39) {
		correct = true
		if (block_trial >= delay) {
			block_acc += 1
		}
	} else if (stim != target && key == 40) {
		correct = true
		if (block_trial >= delay) {
			block_acc += 1
		}
	} else {
		correct = false
	}
	
	jsPsych.data.addDataToLastTrial({
		correct: correct,
		stim: curr_stim,
		trial_num: current_trial
	})
	
	current_trial = current_trial + 1
	within_block_trial = within_block_trial + 1
	block_trial = block_trial + 1
	return correct;
};

// Update variables
// 	** within_block_trial 	tracks trial within a block
//	** current_block		tracks the block we're on
//	** delay				tracks the "N-back load"
//	** new_block			tracks if the block is of a new type
//								if it is, we show a different set of instructions
var new_block_shown = [false, false, false];
var update_params = function() {
	
	// Check if we need to increase or decrease the response deadline
	var count_timeouts = 0
	var experiment_data = jsPsych.data.getTrialsOfType('poldrack-single-stim')
	for(var i = 0; i < experiment_data.length; ++i){
		if(experiment_data[i].rt == -1 & experiment_data[i].block_num == current_block)
			count_timeouts++;
	}
	
	// SLOW DOWN
	// If we have more than 7 timeouts (40%)
	//	and deadline is not already 3500ms (max)
	//	then slow it down by 500ms
	if(count_timeouts > 7 & deadline < 3500) deadline += 500
	
	// SPEED UP
	// If we have fewer than 3 timeouts (10%)
	//	and deadline is not already 2000ms
	//	then speed it up by 500ms
	else if(count_timeouts < 3 & deadline > 2000) deadline -= 500
	
	
	// ALERT
	// If we have more than 12 timeouts (60%)
	//	then show an alert
	if(count_timeouts >= 12 && current_block > 0) setTimeout("tooSlow()", 500);
	
	
	// Trial within block
	within_block_trial = 0;	
	
	// Current block
	current_block += 1
	
	// Update delay
	/*
	if(current_block == 1) delay = 1
	else if(current_block == 2 | current_block == 3 | current_block == 4) delay = 2
	else if(current_block == 5 | current_block == 6 | current_block == 7) delay = 3
	*/
	
	//generate the object sets fresh for each new block
	array = {
			"1": genSet(objects, 1), 
			"2": genSet(objects, 2), 
			"3": genSet(objects, 3),
			}
	
	
	//if we are on the first block or a multiple of num_block...
	if( (current_block-1) % num_blocks == 0) {
		
		//create a list to hold delays and monetary reimbursements
		block_type = [
					{delay: 1, low_reward: rewards[0].low, high_reward: rewards[0].high},
					{delay: 1, low_reward: rewards[1].low, high_reward: rewards[1].high},
					{delay: 2, low_reward: rewards[0].low, high_reward: rewards[0].high},
					{delay: 2, low_reward: rewards[1].low, high_reward: rewards[1].high},
					{delay: 3, low_reward: rewards[0].low, high_reward: rewards[0].high},
					{delay: 3, low_reward: rewards[1].low, high_reward: rewards[1].high},
					]
					
		shuffle(block_type);
		
		/*
		//and create a new order of num_blocks
		delay_order = [1,1,2,2,3,3];
		shuffle(delay_order);
		
		console.log("n-back block order: " + delay_order)
		*/
		console.log("n-back block order: " + block_type)
	}

	//reset the earned rewards
	earned_rewards = 0
	
	//get the current delay (i.e., n in n-back)
	//delay = delay_order[(current_block-1)%num_blocks]
	delay = block_type[(current_block-1)%num_blocks].delay;
	
	//get the high and low rewards
	low_reward  = block_type[(current_block-1)%num_blocks].low_reward;
	high_reward = block_type[(current_block-1)%num_blocks].high_reward;
	
	//calculate a hypothetical total reward amount
	total_reward = (high_reward * (20) / 100).toFixed(2)
	
	console.log("rewards are " + low_reward + "/" + high_reward)

	// Determine if this is a new delay/load
	//	if so, show "first time" instructions (more verbose)
	if(new_block_shown[delay] == false) {
		new_block = 1
		new_block_shown[delay] = true
	} else {
		new_block = 0
	}
	
}

function tooSlow() {
	$.alertable.alert("Whoa! Don't take this the wrong way, but you were going too slow on that last round. Please respond to each animal *before* the next animal appears on the screen.");
}

var update_target = function() {
	if (stims.length >= delay) {
		target = stims.slice(-delay)[0]
	} else {
		target = ""
	}
};

var getStim = function() {
	var trial_type = 'target'
	curr_stim = array[delay][within_block_trial]
	stims.push(curr_stim)
	
	// Refresh if we got to the end
	if(within_block_trial == num_trials + delay){
		array[delay] = genSet(objects, delay)
	}
	
	return '<div class = centerbox><div class = center-text><div class = svg><img class="img" src="stims/'+curr_stim+'" style="max-width:150px"></div></div></div>'
}

var getDeadline = function() {	
	return deadline;
}

var getTarget = function() {
	if(within_block_trial >= delay)
		return array[delay][within_block_trial - delay];
	else return "";
}

var getData = function() {
	return {
		trial_id: "stim_nback",
		exp_stage: "nback_test",
		exp_phase: cur_exp_phase,
		load: delay,
		target: target,
		block_num: current_block,
		stim: array[delay][within_block_trial]
	}
}

var getSliderData = function () {
	return {
		trial_id: "acc_judgment",
		exp_stage: "nback_test",
		exp_phase: cur_exp_phase,
		load: delay,
		block_num: current_block,
	}
}

var getEffortData = function() {
	return {
		trial_id: "stim_ipe",
		exp_stage: "indiff_point_est",
		exp_phase: cur_exp_phase,
		effort_set_id: effort_set_id,
		n_level: curr_stim.n_level[0]+'-vs-'+curr_stim.n_level[1],
		set_trial: 6-curr_stim.trials_left+1,
		hard_value: hard_value,
		easy_value: easy_value,
		inc_value: inc_val,
	}
}


// Instructions for the different N-Backs
//	different instructions are shown for first time and repetitions
var getText = function() {
	
	// First time this type of delay is shown
	if(new_block == 1){
		if(delay == 1)
			return '<div class = centerbox style="height:80vh;text-align:center;"><p class = block-text><font size=24>1 Back (round '+current_block+' of '+display_blocks+')</font><br /><br />Now your will play the 1-back.<br \><br \>Press the RIGHT ARROW for MATCH when the animal you see is the same as <strong><u>1 item back</u></strong>. <br \><br \><br \>Press the DOWN ARROW for MIS-MATCH when the animal you see is different from <strong><u>1 item back</u></strong>.<br \><br \>Below, the current animal is a <strong><u>bee</u></strong>, and the 1-back animal was also a <strong><u>bee</u></strong>, so we have a 1-back match.</p><img src="imgs/1back_diagram.svg" style="max-width:500px"><br /><p class = block-text>This is a test round, so there won\'t be any feedback. It is important that you <strong><u>be as accurate as you can</u></strong>. It is also important that you <strong><u>respond</u></strong> to each animal <strong><u>before the next animal appears</u></strong> on the screen.  <br /><br />Get ready, it will move quickly!<br /><br />Press <strong>enter</strong> to begin.</p><br /><br /></div>';	
		else if(delay == 2)
			return '<div class = centerbox style="height:80vh;text-align:center;"><p class = block-text><font size=24>2 Back (round '+current_block+' of '+display_blocks+')</font><br /><br />Now your will play the 2-back.<br \><br \>Press the RIGHT ARROW for MATCH when the animal you see is the same as <strong><u>2 items back</u></strong>. <br \><br \><br \>Press the DOWN ARROW for MIS-MATCH when the animal you see is different from <strong><u>2 items back</u></strong>.<br \><br \>Below, the current animal is a <strong><u>bee</u></strong>, and the 2-back animal was also a <strong><u>bee</u></strong>, so we have a 2-back match.</p><img src="imgs/2back_diagram.svg" style="max-width:500px"><br /><p class = block-text>This is a test round, so there won\'t be any feedback. It is important that you <strong><u>be as accurate as you can</u></strong>. It is also important that you <strong><u>respond</u></strong> to each animal <strong><u>before the next animal appears</u></strong> on the screen.  <br /><br />Get ready, it will move quickly!<br /><br />Press <strong>enter</strong> to begin.</p><br /><br /></div>';	
		else if (delay == 3)
			return '<div class = centerbox style="height:80vh;text-align:center;"><p class = block-text><font size=24>3 Back (round '+current_block+' of '+display_blocks+')</font><br /><br />Now your will play the 3-back.<br \><br \>Press the RIGHT ARROW for MATCH when the animal you see is the same as <strong><u>3 items back</u></strong>. <br \><br \><br \>Press the DOWN ARROW for MIS-MATCH when the animal you see is different from <strong><u>3 items back</u></strong>.<br \><br \>Below, the current animal is a <strong><u>bee</u></strong>, and the 3-back animal was also a <strong><u>bee</u></strong>, so we have a 3-back match.</p><img src="imgs/3back_diagram.svg" style="max-width:500px"><br /><p class = block-text>This is a test round, so there won\'t be any feedback. It is important that you <strong><u>be as accurate as you can</u></strong>. It is also important that you <strong><u>respond</u></strong> to each animal <strong><u>before the next animal appears</u></strong> on the screen.  <br /><br />Get ready, it will move quickly!<br /><br />Press <strong>enter</strong> to begin.</p><br /><br /></div>';	
		} 
	
	// Not the first time this type of delay is shown
	else if(new_block == 0)
		if(delay == 1)
			return '<div class = centerbox style="height:80vh;text-align:center;"><p class = block-text><font size=24>1 Back (round '+current_block+' of '+display_blocks+')</font><br /><br />Now your will play the 1-back.<br \><br \>Press the RIGHT ARROW for MATCH when the animal you see is the same as <strong><u>1 item back</u></strong>. <br \><br \><br \>Press the DOWN ARROW for MIS-MATCH when the animal you see is different from <strong><u>1 item back</u></strong>.<br \><br \>Below, the current animal is a <strong><u>bee</u></strong>, and the 1-back animal was also a <strong><u>bee</u></strong>, so we have a 1-back match.</p><img src="imgs/1back_diagram.svg" style="max-width:500px"><br /><p class = block-text>This is a test round, so there won\'t be any feedback. It is important that you <strong><u>be as accurate as you can</u></strong>. It is also important that you <strong><u>respond</u></strong> to each animal <strong><u>before the next animal appears</u></strong> on the screen.  <br /><br />Get ready, it will move quickly!<br /><br />Press <strong>enter</strong> to begin.</p><br /><br /></div>';	
		else if(delay == 2)
			return '<div class = centerbox style="height:80vh;text-align:center;"><p class = block-text><font size=24>2 Back (round '+current_block+' of '+display_blocks+')</font><br /><br />Now your will play the 2-back.<br \><br \>Press the RIGHT ARROW for MATCH when the animal you see is the same as <strong><u>2 items back</u></strong>. <br \><br \><br \>Press the DOWN ARROW for MIS-MATCH when the animal you see is different from <strong><u>2 items back</u></strong>.<br \><br \>Below, the current animal is a <strong><u>bee</u></strong>, and the 2-back animal was also a <strong><u>bee</u></strong>, so we have a 2-back match.</p><img src="imgs/2back_diagram.svg" style="max-width:500px"><br /><p class = block-text>This is a test round, so there won\'t be any feedback. It is important that you <strong><u>be as accurate as you can</u></strong>. It is also important that you <strong><u>respond</u></strong> to each animal <strong><u>before the next animal appears</u></strong> on the screen.  <br /><br />Get ready, it will move quickly!<br /><br />Press <strong>enter</strong> to begin.</p><br /><br /></div>';	
		else if (delay == 3)
			return '<div class = centerbox style="height:80vh;text-align:center;"><p class = block-text><font size=24>3 Back (round '+current_block+' of '+display_blocks+')</font><br /><br />Now your will play the 3-back.<br \><br \>Press the RIGHT ARROW for MATCH when the animal you see is the same as <strong><u>3 items back</u></strong>. <br \><br \><br \>Press the DOWN ARROW for MIS-MATCH when the animal you see is different from <strong><u>3 items back</u></strong>.<br \><br \>Below, the current animal is a <strong><u>bee</u></strong>, and the 3-back animal was also a <strong><u>bee</u></strong>, so we have a 3-back match.</p><img src="imgs/3back_diagram.svg" style="max-width:500px"><br /><p class = block-text>This is a test round, so there won\'t be any feedback. It is important that you <strong><u>be as accurate as you can</u></strong>. It is also important that you <strong><u>respond</u></strong> to each animal <strong><u>before the next animal appears</u></strong> on the screen.  <br /><br />Get ready, it will move quickly!<br /><br />Press <strong>enter</strong> to begin.</p><br /><br /></div>';	
		}

// Get a random number between min and max
function getRand(min, max) {
  return Math.round(Math.random() * (max - min) + min);
}

//	CNBM = Count N Back Matches, where N is the N-back level
//		helper to genSet (below)
var cnbm = function(stim_arr, n) {
	count_matches = 0;
	for (var i = n; i < stim_arr.length; i++) {
		if(stim_arr[i] == stim_arr[i-n]){
			count_matches++;
		}
	}
	return count_matches;
}

// Generate a block
//	this is set to generate a block of length 20 with 7 targets
function genSet(array, n){
	
	// Loop until we have exactly 7 targets
	while ( cnbm(array, n) != 7 ) {
		
		len = 20		
		array = objects;
		
		// Generate intial array by concatenation up to length, then shuffle
		for (var i = 1; i < len / objects.length; i++) {
			array = jsPsych.randomization.shuffle( array.concat(objects) )
		}	
		
		// Append n objects to end of array
		//	because first n objects don't have any targets
		for (var i = 1; i <= n; i++) {
			array = array.concat(objects[getRand(0, objects.length - 1)])
		}	
	   
	   // Add targets to array at random
		for (var i = n; i < 7; i++) {
			x = getRand(n + n, array.length - 1)
			array[x] = array[x - n]
		}		
	}
	
	return array;
}


// Used to present a demo of the stimulus presentation in instructions
var slides = function(){
	
	function nextSlide() {
		slides[currentSlide].className = 'slide';
		currentSlide = (currentSlide+1)%slides.length;
		slides[currentSlide].className = 'slide showing';
	}	
	var slides = document.querySelectorAll('#slides .slide');
	var currentSlide = 0;
	var slideInterval = setInterval(nextSlide,1000);

};


/* ************************************ */
/* Define experimental variables */
/* ************************************ */
// generic task variables
var run_attention_checks = true
var attention_check_thresh = 0.65
var sumInstructTime = 0 //ms
var instructTimeThresh = 0 ///in seconds
var credit_var = true //default to true

// task specific variables
var num_blocks = 6 // number of test blocks
var num_trials = 2 // total num_trials
var block_acc = 0 // record block accuracy to determine next blocks delay
var delay = 1 // starting delay
var trials_left = 0 // counter used by test_node
var target_trials = [] // array defining whether each trial in a block is a target trial
var current_trial = 0
var within_block_trial = 1
var current_block = 0
var block_trial = 0
var target = ""
var curr_stim = ''
var new_block = 0
var deadline = 2000 // Start at 2000ms, and "adapt" to performance
					// 		since the N-Back is primarily about accuracy
					// 		and not speed, we don't want to put those with
					// 		slower response times at a disadvantage
var timeouts_last_block = 0 // hold # of timeouts on last block
var stims = [] //hold stims per block
var correct_response = ""



/*
###############
Credits
	for images
###############

	fish.svg
	lobster.svg
	whale.svg
	bee.svg
	butterfly.svg
	tortoise.svg
	pig.svg
	elephant.svg
	parrot.svg

	Author: Freepik
	Sources: 
	https://www.flaticon.com/packs/sea-life-collection
	https://www.flaticon.com/packs/animals-19/2
	https://www.flaticon.com/free-icon/tortoise_1045269
	https://www.flaticon.com/free-icon/elephant_427560
	https://www.flaticon.com/free-icon/pig_616547X
	https://www.flaticon.com/free-icon/parrot_427487
	
###############
*/

var objects = [
	"fish.svg",
	"lobster.svg",
	"whale.svg",
	"bee.svg",
	"butterfly.svg",
	"tortoise.svg",
	"pig.svg",
	"elephant.svg",
	"parrot.svg",
	"lion.svg"
]

// Initial shuffle
objects = jsPsych.randomization.shuffle(objects)

// Preload all images
if (document.images) {
	for (var i = 0; i < objects.length; i++) {
		window["stims_"+i] = new Image();
		window["stims_"+i].src = "stims/"+objects[i];
	}
	window["instr1"] = new Image();
	window["instr2"] = new Image();
	window["instr3"] = new Image();
	window["instr4"] = new Image();
	window["instr5"] = new Image();
	window["instr1"].src = "imgs/1back_diagram.svg";
	window["instr2"].src = "imgs/1back_diagram_nonmatch.svg";
	window["instr3"].src = "imgs/2back_diagram.svg";
	window["instr4"].src = "imgs/3back_diagram.svg";
	window["instr5"].src = "imgs/arrow_keys.svg";
}

//####################################################
//####################################################


/* ************************************ */
/* Set up jsPsych blocks */
/* ************************************ */
// Set up attention check node
//	 give 7.5 seconds to respond to each

var my_attn_qs = [{'Q': '<p>ATTENTION CHECK</p> <p>Press the Spacebar</p>', 'A': 32}, 
				  {'Q': '<p>ATTENTION CHECK</p> <p>Press the "8" key</p>',  'A': 56}]

var attention_index = 0
var attention_check_block = {
	type: 'attention-check',
	data: {
		trial_id: "attention"
	},
	timing_response: 7500,
	response_ends_trial: true,
	timing_post_trial: 200
}

var getAttentionQ = function() {
	if(attention_index == 1) attention_index += 1
	return my_attn_qs[attention_index]['Q']
}
var getAttentionA = function() {
	if(attention_index == 1) attention_index += 1
	return my_attn_qs[attention_index]['A']
}

var attention_node = {
	timeline: [attention_check_block],
	question: getAttentionQ,
	key_answer: getAttentionA,
	conditional_function: function() {
		return run_attention_checks
	}
}


/* define static blocks */
var feedback_instruct_text =
	'<div class = centerbox style="height:80vh"><p class = block-text>Let\'s play a memory game! Focus will be important here, so before we begin please make sure you\'re ready for about <u><strong>thirty minutes</strong></u> of uninterrupted game time! You will have opportunity to take short breaks throughout.</p> <p class = block-text>Press <strong>enter</strong> to continue.</p></div>'
var feedback_instruct_block = {
	type: 'poldrack-text',
	cont_key: [13],
	data: {
		trial_id: 'instruction'
	},
	text: getInstructFeedback,
	timing_post_trial: 0,
	timing_response: 180000
};
var instructions_block = {
	type: 'poldrack-instructions',
	pages: [
		'<div class = centerbox style="height:80vh"><p class = block-text>In this game you will see a series of animals.<br/></p><table style="width:100%"> <tr> <td style="text-align:center;width:50%"><img src="stims/'+objects[1]+'" style="max-width:150px"></td> <td style="text-align:center;width:50%"><img src="stims/'+objects[2]+'" style="max-width:150px"></td> </tr> </table><br/><p class = block-text>Your goal is to identify when an animal is the same or different from the one you saw <strong><u>N-items back</u></strong> in the sequence.<br \><br \>"N" is the number of items that you need to keep in memory.</p></div>'
	],
	data: {
		trial_id: 'instruction'
	},
	allow_keys: false,
	show_clickable_nav: true,
	timing_post_trial: 1000
};
var instructions_block2 = {
	type: 'poldrack-instructions',
	pages: [
		'<div class = centerbox style="height:80vh;text-align:center;"><p class = block-text><font size=24>1 Back</font><br /><br />Let\'s start with the 1-back.<br /><br />The object of the 1-back is to identify when the animal you see is the same or different from the animal you saw <strong><u>1 item back</u></strong>.<br \><br \>In the example below, the current animal is a <strong><u>bee</u></strong>, and 1-back animal was also a <strong><u>bee</u></strong>, so we have a 1-back match!</p><img src="imgs/1back_diagram.svg" style="max-width:500px"></div>'
	],
	data: {
		trial_id: 'instruction'
	},
	allow_keys: false,
	show_clickable_nav: true,
	timing_post_trial: 1000
};
var instructions_block3 = {
	type: 'poldrack-instructions',
	pages: [
		'<div class = centerbox style="height:80vh;text-align:center;"><p class = block-text><font size=24>1 Back</font><br /><br />You will also identify mis-matches. <br \><br \>In the example below, the current object is a <strong><u>bee</u></strong> but the 1-back animal was a <strong><u>whale</u></strong>, so we have a 1-back mis-match. </p><img src="imgs/1back_diagram_nonmatch.svg" style="max-width:500px"></div>'
	],
	data: {
		trial_id: 'instruction'
	},
	allow_keys: false,
	show_clickable_nav: true,
	timing_post_trial: 1000
};
var instructions_block4 = {
	type: 'poldrack-instructions',
	pages: [
		'<script>slides();</script><div class = centerbox style="height:80vh"><p class = block-text><font size=24>1 Back</font><br /><br />The animals will be presented one after another in a sequence like the animation below. Can you spot the 1-back matches and mis-matches? <br \><br \><ul id="slides"><li class="slide showing"><img src="stims/'+objects[1]+'" style="max-width:150px"></li> <li class="slide "></li> <li class="slide"><img src="stims/'+objects[1]+'" style="max-width:150px"></li><li class="slide "></li> <li class="slide "><img src="stims/'+objects[3]+'" style="max-width:150px"></li> <li class="slide "></li> <li class="slide"><img src="stims/'+objects[2]+'" style="max-width:150px"></li><li class="slide "> </ul><br /></div>'
	],
	data: {
		trial_id: 'instruction'
	},
	allow_keys: false,
	show_clickable_nav: true,
	timing_post_trial: 1000
};
var instructions_block5 = {
	type: 'poldrack-instructions',
	pages: [
		'<div class = centerbox style="height:80vh;text-align:center;"><p class = block-text><font size=24>1 Back</font><br /><br />Place your fingers on the <strong><u>right arrow</u></strong> and <strong><u>down arrow</u></strong> keys.<br \><br \><strong><u>MATCH:</u></strong> If you see an object that\'s a 1-back match press the <strong><u>right arrow</u></strong> key.<br /><br /><strong><u>MIS-MATCH:</u></strong> If you see an object that\'s 1-back mis-match press the <strong><u>down arrow</u></strong> key.</p><img src="imgs/arrow_keys.svg" style="max-width:500px"><br /></div>'
	],
	data: {
		trial_id: 'instruction'
	},
	allow_keys: false,
	show_clickable_nav: true,
	timing_post_trial: 1000
};
var instruction_node = {
	timeline: [instructions_block, instructions_block2, instructions_block3, instructions_block4, instructions_block5]
}


////////////////////////////////////////////////////////////////////////
// 	NEW PHASE 1 INSTRUCTIONS
/*
var instructions_phase1_block1 = {
	type: 'poldrack-instructions',
	pages: [
		'<div class = centerbox style="height:80vh"><p class = block-text>PHASE 1 INSTRUCTIONS GO HERE</p></div>'
	],
	data: {
		trial_id: 'instruction'
	},
	allow_keys: false,
	show_clickable_nav: true,
	timing_post_trial: 1000
};
*/
var instruction_phase1_node = {
	timeline: [instructions_block, instructions_block2, instructions_block3, instructions_block4, instructions_block5]
}


////////////////////////////////////////////////////////////////////////
// 	NEW PHASE 2 INSTRUCTIONS
var instructions_phase2_block1 = {
	type: 'poldrack-instructions',
	pages: [
		'<div class = centerbox style="height:80vh"><p class = block-text>Now we\'re going to play a different game. In this game you are going to be asked whether you would like to do a 1-back, 2-back, or 3-back task. For each choice you will also be shown a dollar amount that you would get paid if you did this task. Each time you are presented with a choice, press the LEFT or RIGHT arrows to pick the left or right choice.</p></div>'
	],
	data: {
		trial_id: 'instruction'
	},
	allow_keys: false,
	show_clickable_nav: true,
	timing_post_trial: 1000
};
var instruction_phase2_node = {
	timeline: [instructions_phase2_block1]
}


////////////////////////////////////////////////////////////////////////
// 	NEW PHASE 3 INSTRUCTIONS
var instructions_phase3_block1 = {
	type: 'poldrack-instructions',
	pages: [
		'<div class = centerbox style="height:80vh"><p class = block-text>PHASE 3 INSTRUCTIONS GO HERE. Now we will play the n-back again, but you will be paid for accurate performance </p></div>'
	],
	data: {
		trial_id: 'instruction'
	},
	allow_keys: false,
	show_clickable_nav: true,
	timing_post_trial: 1000
};
var instruction_phase3_node = {
	timeline: [instructions_phase3_block1]
}


////////////////////////////////////////////////////////////////////////
// 	NEW FEEDBACK SCREEN
var getFeedback = function() {

	//calculate the block accuracy percentage
	var acc_per = 100 * block_acc / num_trials;
	
	console.log("block_acc: " + block_acc + " num_trials: " + num_trials + " > " + acc_per);
	
	//construct the feedback html
	//var fb = '<div class = centerbox style="height:80vh;text-align:center;"><p class = "center-block-text"><font size=24>Feedback</font><br /><br />How often were you correct?<br \><br \>'
	var fb = '<div class = centerbox style="height:80vh;text-align:center;"><p class = "center-block-text">How often were you correct?<br \>'
	
	fb += '<table width=100%><tbody><tr>';
	fb += '<td width=20%><font size=6>0%</font></td>';
	fb += '<td width=60%>';
	fb += '<div id="progress" style="background: #333; border-radius: 13px; height: 20px; width: 100%; padding: 3px; align: center; text-align: center; vertical-align: middle; position: relative;">';
	fb += '<div id="bar" style="width: '+acc_per+'%; height: 20px; background-color: #00A2FF; border-radius: 13px; position: absolute; z-index: 2;"></div>';
	fb += '</div>';
	fb += '</td>';
	fb += '<td width=20%><font size=6>100%</font></td>';
	
	fb += '</tr></tbody></table>';

	fb += '<p class = center-block-text>Press <strong>enter</strong> to proceed</p>';
	
	fb += '</p><br /><br /></div>';
	
	return fb;
}

var getEndBlock = function() {
	
	//calculate the earned rewards
	earned_rewards = (block_acc * high_reward) + ((num_trials-block_acc) * low_reward)
	total_earned_rewards += earned_rewards; 

	console.log("block_acc: " + block_acc + " num_trials: " + num_trials + " > " + earned_rewards);
	
	var fb = '';
	
	//if there were rewards...
	if(high_reward > 0 || low_reward > 0) {
	
	
		//then monetary feedback
		fb = 'You won $' + (earned_rewards/100).toFixed(2) + ' for this round<br><br>You can take a short break for 30 seconds.'
	
	//no rewards
	} else {
	
		//generic block ending feedback
		fb = 'You finished this round!<br><br>You can take a short break.'
	}
	
	return '<div class = "centerbox"><p class = "center-block-text">'+fb+'</p><p class = center-block-text>Press <strong>enter</strong> when you are ready for the next round!</p></div>';
}

var getEndBlockTime = function() {
	
	//if there were rewards...
	if(high_reward > 0 || low_reward > 0) {
		
		//30 second break
		return 30000
	}
	
	//default 180 second break (3 mins)
	return 180000
}



//get the text informing the subject about the amount of reward they could win
var getRewardText = function() {
	return '<div class = "centerbox"><p class = block-text><font size=24>'+delay+' Back (round '+current_block+' of '+display_blocks+')</font><br /><br />In this round, you can earn '+high_reward+'¢ for each animal you see for a total possible reward of $'+total_reward+'!<br><br>You will get '+high_reward+'¢ added to your bonus each time you are correct!</p><p class = center-block-text>Press <strong>enter</strong> when you are ready to begin!</p></div>';
}


var block_feedback = {
	type: 'poldrack-text',
	data: {
		exp_stage: "test",
		trial_id: "block_feedback"
	},
	text: getFeedback,
	cont_key: [13],
	timing_response: 900000
};


var block_sliding_clear = {
	type: 'call-function',
	func: function() {
			slider_value = 50
		},
	data: {
		trial_id: "set_feedback_slider"
	},
	timing_post_trial: 0
}

slider_value = 50;
var block_sliding_feedback = {
	type: 'poldrack-instructions',
	pages: [
		'<div class = centerbox style="height:80vh;text-align:center;"><p class = "center-block-text">How often were you correct?<br \><div class="slidecontainer">0%<input type="range" min="1" max="100" value="'+slider_value+'" class="slider" id="myCorrectRange" width="50%" onChange="slider_value = this.value">100%</div></p></div>',
	],
	data: getSliderData,
	on_finish: function() {
		console.log('judged accuracy: ' + slider_value)
		
		jsPsych.data.addDataToLastTrial({
			judged_acc: slider_value,
		})
	},
	allow_keys: false,
	show_clickable_nav: true,
	timing_post_trial: 1000
};


// Credit for keyboard vector used in instructions
// Author: Kevin Burke
// https://www.vectorportal.com/StockVectors/Icons/ARROW-KEYS-FREE-VECTOR/9459.aspx

var end_block = {
	type: 'poldrack-text',
	text: getEndBlock,
	cont_key: [13],
	data: {
		trial_id: "end_block",
    	exp_id: 'test_n_back'
	},
	timing_response: getEndBlockTime,
	timing_post_trial: 0,
	//on_finish: assessPerformance
	on_finish: function(){ 
		jsPsych.data.addDataToLastTrial({
			exp_phase: cur_exp_phase,
			block_num: current_block,
			won_amount: (earned_rewards/100).toFixed(2),
		})

		saveData(subj_id, jsPsych.data.dataAsCSV()); 
		}
};


var end_exp = {
	type: 'poldrack-text',
	text: '<div class = "centerbox"><p class = "center-block-text">You finished the experiment!<br><br>Thank you for participating.</p><p class = center-block-text>Press <strong>enter</strong> to end ths study.</p></div>',
	cont_key: [13],
	data: {
		trial_id: "end_exp",
    	exp_id: 'test_n_back'
	},
	timing_response: 180000,
	timing_post_trial: 0,
	on_finish: assessPerformance
};

var start_phase1_practice_block = {
	type: 'poldrack-text',
	text: '<div class = centerbox><p class = block-text><p class = block-text><font size=24>Practice</font><br /><br />Let\'s practice.<br /><br />During practice you\'ll see if you are correct or incorrect after responding. After practice we\'ll go again but without the correct / incorrect feedback.<br /><br /> Press <strong>enter</strong> to begin.</p></div>',
	cont_key: [13],
	data: {
		trial_id: "instruction"
	},
	timing_response: 180000,
	timing_post_trial: 1000
};

var start_phase3_practice_block = {
	type: 'poldrack-text',
	text: '<div class = centerbox><p class = block-text><p class = block-text><font size=24>Practice</font><br /><br />Let\'s practice.<br /><br />During practice you\'ll see if you are correct or incorrect after responding. After practice we\'ll go again but without the correct / incorrect feedback.<br /><br /> Press <strong>enter</strong> to begin.</p></div>',
	cont_key: [13],
	data: {
		trial_id: "instruction"
	},
	timing_response: 180000,
	timing_post_trial: 1000
};

var update_exp_phase = {
	type: 'call-function',
	func: function() { cur_exp_phase += 1; current_block = 0; total_earned_rewards = 0; },
	data: {
		trial_id: "update_exp_phase"
	},
	timing_post_trial: 0
}

var set_no_rewards = {
	type: 'call-function',
	func: function() { rewards = [{low: 0, high: 0}, {low:0, high: 0}]; },
	data: {
		trial_id: "set_rewards"
	},
	timing_post_trial: 0
}

var set_5n25_rewards = {
	type: 'call-function',
	func: function() { rewards = [{low: 0, high: 5}, {low:0, high: 25}]; },
	data: {
		trial_id: "set_rewards"
	},
	timing_post_trial: 0
}


var double_display_blocks = {
	type: 'call-function',
	func: function () {	display_blocks = num_blocks * 2; },
	data: {
		trial_id: "double_display_blocks"
	},
	timing_post_trial: 0
}


var update_params_block = {
	type: 'call-function',
	func: update_params,
	data: {
		trial_id: "update_params_block"
	},
	timing_post_trial: 0
}

var update_target_block = {
	type: 'call-function',
	func: update_target,
	data: {
		trial_id: "update_target"
	},
	timing_stim: 0,
	timing_post_trial: 0
}

var start_test_block = {
	type: 'poldrack-text',
	data: {
		exp_stage: "test",
		trial_id: "delay_text"
	},
	text: getText,
	cont_key: [13],
	timing_response: 900000,
	on_finish: function() {
		block_trial = 0
		stims = []
		trials_left = num_trials + delay
		target_trials = []
		block_acc = 0;
	}
};

var inform_reward_block = {
	type: 'poldrack-text',
	data: {
		exp_stage: "test",
		trial_id: "inform_reward"
	},
	text: getRewardText,
	cont_key: [13],
	timing_response: 900000,
};


// ######################################################
// ######################################################

//#######################
// 1-back practice

//this function will create a set of practice trials with correct/incorrect feedback messages as needed
function genPracticeTrials(correct_text_param, incorrect_text_param, timeout_text_param) {
	practice_trials = []
	array = genSet(objects, 1)
	for (var i = 0; i < (num_trials+1); i++) {
		var stim = array[i]
		stims.push(stim)
		
		if (i > 0) target = array[i - 1];
		if (stim == target) correct_response = 39;
			else correct_response = 40;
		
		if(i == 0){
			correct_text = "&nbsp;"
			incorrect_text = "&nbsp;"
			timeout_message = "&nbsp;"
			show_stim_with_feedback = false
		} else {		
			correct_text = correct_text_param;
			timeout_message = timeout_text_param;
			incorrect_text = incorrect_text_param;
			show_stim_with_feedback = true
			}
		
		var practice_block = {
			type: 'poldrack-categorize',
			is_html: true,
			stimulus: '<div class = centerbox><div class = center-text><div class = svg><img class="img" src="stims/'+stim+'" style="max-width:150px"></div></div></div>',
			key_answer: correct_response,
			data: {
				trial_id: "stim",
				exp_stage: "practice",
				stim: stim,
				target: target
			},
			correct_text: correct_text,
			incorrect_text: incorrect_text,
			timeout_message: timeout_message,
			timing_feedback_duration: 500,
			show_stim_with_feedback: false,
			response_ends_trial: false,
			choices: [39,40],
			timing_stim: 500,
			timing_response: deadline,
			timing_post_trial: 500
		};
		practice_trials.push(practice_block)
	}
	
	return practice_trials
}

//create some feedback only practice trials
corrText = '<div class = fb_box style="border: 20px solid green"><div class = center-text style="font-size:inherit"><font size = 20>correct</font></div></div>';
incorrText = '<div class = fb_box style="border: 20px solid red"><div class = center-text style="font-size:inherit"><font size = 20>incorrect</font></div></div>';
timeoutText = '<div class = fb_box style="border: 20px solid red"><div class = center-text style="font-size:inherit"><font size = 20>too slow</font></div></div>';
practice_trials_phase1 = genPracticeTrials(corrText, incorrText, timeoutText);

//create some monetary feedback practice trials
corrText = '<div class = fb_box style="border: 20px solid green"><div class = center-text style="font-size:inherit"><font size = 20>5 cents</font></div></div>';
incorrText = '<div class = fb_box style="border: 20px solid red"><div class = center-text style="font-size:inherit"><font size = 20>0 cents</font></div></div>';
timeoutText = '<div class = fb_box style="border: 20px solid red"><div class = center-text style="font-size:inherit"><font size = 20>too slow</font></div></div>';
practice_trials_phase3 = genPracticeTrials(corrText, incorrText, timeoutText);



//#######################
// All other blocks
var test_block = {
	type: 'poldrack-single-stim',
	is_html: true,
	target: getTarget,
	stimulus: getStim,
	data: getData,
	correct_response: correct_response,
	choices: [39,40],
	
	timing_stim: 500,
	//timing_stim: 5,
	
	timing_response: getDeadline,
	//timing_response: 5,
	
	timing_post_trial: 0,
	on_finish: function(data) {
			record_acc(data, target)
			console.log("trial " + (num_trials-trials_left) + ": " + delay + "-back > " + curr_stim + " " + target)
	}
}; 

var test_node = {
	timeline: [update_target_block, test_block],
	loop_function: function() {
		trials_left -= 1
		if (trials_left === 0) {
			return false
		} else { 
			return true 
		}
	}
}

//////////////////// INDIFFERENCE POINT FUNCTIONS //////////////////////

function get_current_increment(start_value, total_trials, trials_left) {
	return roundTo(start_value/(2**(total_trials-trials_left+1)),2)
}


//returns HTML formatted pair of effort values based on the indifference point algorithm
var effort_stimulus = '';
var getEffortStim = function() {
	var trial_type = 'effort'
	
	//check that at least one stim is valid
	for(var i = 0; i < effort_trials.length; i++) {
		if(effort_trials[i].trials_left > 0)break
	}
	
	//TODO deal with this case
	if(i == effort_trials.length) {
		console.log('no effort trials remain...')
		return '<div class = centerbox><div class = center-text>no choices left</div></div>'
	}
	
	//find an effort trial to deal with
	while(true) {
		r = getRand(0, effort_trials.length-1)
		if(effort_trials[r].trials_left > 0)break
	}
	
	//save the current stimulus
	curr_stim = effort_trials[r]
	stims.push(curr_stim)
	
	effort_set_id = r
	
	//calculate the hard and easy values using the indifference point algorithm
	inc_val = get_current_increment(curr_stim.start_val, effort_num_trials, curr_stim.trials_left)
	hard_value = (curr_stim.cur_val + inc_val).toFixed(2)
	easy_value = (curr_stim.cur_val - inc_val).toFixed(2)
	
	console.log('trial ' + block_trial + ' -> ' + r + ': ' + curr_stim.n_level[0] + '-vs-' + curr_stim.n_level[1] + '(' + hard_value + ') or 1(' + easy_value + ')')
	
	var eff_label = []
	var eff_value = []
	
	//by default put the hard choice on the left
	eff_label.push(curr_stim.n_level[0]+'-Back')
	eff_value.push(hard_value)
	
	eff_label.push(curr_stim.n_level[1]+'-Back')
	eff_value.push(easy_value)
	
	//shuffle the location of the hard response
	hard_response = shuffle([37,39])[0]
	
	//if the hard response should be on the right
	if(hard_response == 39) {
		
		//reverse the labels and values
		eff_label = eff_label.reverse()
		eff_value = eff_value.reverse()
	}
	
	effort_stimulus = '<div class = centerbox style="height:80vh"><div class = center-text style="font-size: 20px;"><table style="width:100%"> <tr> <td style="width:10%"></td> <td style="text-align:center;width:35%"><div id="left_item">'+eff_label[0]+'<br>'+eff_value[0]+'</div></td> <td style="width:10%"></td> <td style="text-align:center;width:35%"><div id="right_item">'+eff_label[1]+'<br>'+eff_value[1]+'</div></td> <td style="width:10%"></td> </tr> </table></div></div>';
	
	return effort_stimulus
}

var getEffortStimFeedback = function() {
	new_style = 'border-style: solid; border-color: #ffffff; border-width: 5px;'
	return effort_stimulus.replace(resp_side+'_item"', resp_side+'_item" style="'+new_style+'"');
}



var start_effort_block = {
	type: 'call-function',
	func: function() {
		block_trial = 0
		stims = []
		trials_left = effort_num_trials*effort_trials.length
		target_trials = []
		block_acc = 0;
	},
	data: {
		trial_id: "start_effort_block"
	},
	timing_post_trial: 0
}


var record_effort_acc = function(data, t) {
	
	var key = data.key_press
	
	//determine left/right for upcoming feedback
	if(key == 37)
		resp_side = 'left'
	else
		resp_side = 'right'
	
	//hard response, increment payment
	if(key == hard_response) {
		diff_chosen_resp = 'hard'
		curr_stim.cur_val += inc_val
		
		console.log('hard value selected: ' + curr_stim.cur_val)
	}
	//easy response, decrease payment
	else {
		diff_chosen_resp = 'easy'
		curr_stim.cur_val -= inc_val
		
		console.log('easy value selected: ' + curr_stim.cur_val)
	}
	
	curr_stim.trials_left -= 1
	
	jsPsych.data.addDataToLastTrial({
		chosen_opt: diff_chosen_resp,
		chosen_value: curr_stim.cur_val,
	})
	
	current_trial = current_trial + 1
	block_trial = block_trial + 1
	
};


var effort_block = {
	type: 'poldrack-single-stim',
	is_html: true,
	target: getTarget,
	stimulus: getEffortStim,
	data: getEffortData,
	choices: [37,39],
	
	//timing_stim: 5000,
	//timing_response: 5000,
	response_ends_trial: true,
	
	timing_post_trial: 0,
	on_finish: function(data) {
			record_effort_acc(data)
			//console.log("trial " + (num_trials-trials_left) + ": " + delay + "-back > " + curr_stim + " " + target)
	}
}; 


var effort_feedback_block = {
	type: 'poldrack-single-stim',
	is_html: true,
	stimulus: getEffortStimFeedback,
	choices: ['5'], //dummy key, not intended to be pressed
	timing_response: 500,
	response_ends_trial: false,
};

var effort_node = {
	timeline: [effort_block, effort_feedback_block],
	loop_function: function() {
		trials_left -= 1
		if (trials_left === 0) {
			return false
		} else { 
			return true 
		}
	}
}

//Set up experiment
var adaptive_n_back_experiment = []

////////////////////////////////////////////////////////////////////////
//		Phase 1 - Baseline N-Back
////////////////////////////////////////////////////////////////////////

//current experimental phase
cur_exp_phase = 0

//update the experiment phase
adaptive_n_back_experiment.push(update_exp_phase)

//		initiate the rewards level
rewards = [{low: 0, high: 0}, {low:0, high: 0}];
high_reward = 0
low_reward = 0
total_earned_rewards = 0

//		set the default display blocks number
display_blocks = num_blocks;

// 		Instructions
//adaptive_n_back_experiment.push(instruction_phase1_node);

//		PRACTICE
//		1-Back w. Feedback (correct/incorrect)
//adaptive_n_back_experiment.push(start_phase1_practice_block)
//adaptive_n_back_experiment = adaptive_n_back_experiment.concat(practice_trials_phase1)


//set the rewards level to none
adaptive_n_back_experiment.push(set_no_rewards)
				
//		6 blocks -> 2x 1-Back, 2-Back, 3-Back, randomized order
for (var b = 1; b <= num_blocks; b++) { 
//for (var b = 1; b <= 2; b++) { 
	
	adaptive_n_back_experiment.push(update_params_block)
	adaptive_n_back_experiment.push(start_test_block)
	adaptive_n_back_experiment.push(test_node)

	//adaptive_n_back_experiment.push(test_feedback_node)
	if(b % 3 == 0){ // run an attention check every 3 blocks
		adaptive_n_back_experiment.push(attention_node)
	}
	
	//feedback
	adaptive_n_back_experiment.push(block_sliding_clear)
	adaptive_n_back_experiment.push(block_sliding_feedback);
	adaptive_n_back_experiment.push(end_block);
}



////////////////////////////////////////////////////////////////////////
//		Phase 2 - Effort Discounting Decisions
////////////////////////////////////////////////////////////////////////

//update the experiment phase
adaptive_n_back_experiment.push(update_exp_phase)

//		54 trials...
//			2v1, 3v1, and 3v2 -> 3x each -> 6 estimates per instance

effort_start_val = 1	//starting value for the algorthim (1 = $1.00)
effort_num_trials = 6	//number of decisions to offer per instance

//all instances for the loop
effort_trials = [
	{n_level: [2,1], trials_left: effort_num_trials, start_val: effort_start_val, cur_val: effort_start_val},
	{n_level: [2,1], trials_left: effort_num_trials, start_val: effort_start_val, cur_val: effort_start_val},
	{n_level: [2,1], trials_left: effort_num_trials, start_val: effort_start_val, cur_val: effort_start_val},
	
	{n_level: [3,1], trials_left: effort_num_trials, start_val: effort_start_val, cur_val: effort_start_val},
	{n_level: [3,1], trials_left: effort_num_trials, start_val: effort_start_val, cur_val: effort_start_val},
	{n_level: [3,1], trials_left: effort_num_trials, start_val: effort_start_val, cur_val: effort_start_val},

	{n_level: [3,2], trials_left: effort_num_trials, start_val: effort_start_val, cur_val: effort_start_val},
	{n_level: [3,2], trials_left: effort_num_trials, start_val: effort_start_val, cur_val: effort_start_val},
	{n_level: [3,2], trials_left: effort_num_trials, start_val: effort_start_val, cur_val: effort_start_val},
	]

// 		Instructions
adaptive_n_back_experiment.push(instruction_phase2_node);

//		Trials
adaptive_n_back_experiment.push(start_effort_block);
adaptive_n_back_experiment.push(effort_node);

//		End the block
adaptive_n_back_experiment.push(end_block);


////////////////////////////////////////////////////////////////////////
//		Phase 3 - Rewarded N-Back
////////////////////////////////////////////////////////////////////////

//update the experiment phase
adaptive_n_back_experiment.push(update_exp_phase)

// 		Instructions
adaptive_n_back_experiment.push(instruction_phase3_node);

//		PRACTICE
//		1-Back w. Feedback (0 cents/5 cents)
adaptive_n_back_experiment.push(start_phase3_practice_block)
adaptive_n_back_experiment = adaptive_n_back_experiment.concat(practice_trials_phase3)

//set the rewards level to 5 and 25
adaptive_n_back_experiment.push(set_5n25_rewards)

//change the number of blocks to display for feedback screens
adaptive_n_back_experiment.push(double_display_blocks)

//		12 blocks -> 2x 1-Back, 2-Back, 3-Back all at 25/5 cents, randomized order
for (var b = 1; b <= num_blocks*2; b++) { 
//for (var b = 1; b <= 2; b++) { 

	adaptive_n_back_experiment.push(update_params_block)
	adaptive_n_back_experiment.push(start_test_block)
	adaptive_n_back_experiment.push(inform_reward_block)
	adaptive_n_back_experiment.push(test_node)

	if(b % 3 == 0){ // run an attention check every 3 blocks
		adaptive_n_back_experiment.push(attention_node)
	}
	
	//feedback
	adaptive_n_back_experiment.push(block_sliding_clear)
	adaptive_n_back_experiment.push(block_sliding_feedback);
	adaptive_n_back_experiment.push(end_block);
}

//		End Experiment
adaptive_n_back_experiment.push(end_exp)



//#################################################################################################
//#################################################################################################
//#################################################################################################
// Inject a CSS and JS file for custom alerts
//		this way we don't have to modify the index.html file
var link = document.createElement("link");
link.href = "css/jquery.alertable.css";
link.type = "text/css";
link.rel = "stylesheet";
document.getElementsByTagName("head")[0].appendChild(link);

var script = document.createElement('script');
script.setAttribute('src', 'js/jquery.alertable.min.js');
script.setAttribute('type', 'text/javascript');
document.getElementsByTagName('head')[0].appendChild(script);


